@@ -1,4 +1,5 @@
 import os
+
 import pkg_resources
 
 PREFIX = "SC-P--"
@@ -23,6 +24,10 @@ MAPPINGS = "mappings"
 LAUNCHES = "launches"
 SPOKE_LOCAL_PORTFOLIOS = "spoke-local-portfolios"
 LAMBDA_INVOCATIONS = "lambda-invocations"
+ASSERTIONS = "assertions"
+ASSERTION = "assertion"
+CODE_BUILD_RUNS = "code-build-runs"
+CODE_BUILD_RUN = "code-build-run"
 ACTIONS = "actions"
 
 LAUNCH = "launch"
@@ -30,6 +35,8 @@ LAMBDA_INVOCATION = "lambda-invocation"
 SPOKE_LOCAL_PORTFOLIO = "spoke-local-portfolio"
 ACTION = "action"
 
+AFFINITY = "affinity"
+
 RESULTS_DIRECTORY = "results"
 
 NO_CHANGE = "NO_CHANGE"
@@ -95,3 +102,6 @@ CONFIG_SHOULD_EXPLODE_MANIFEST = "should_explode_manifest"
 PUBLISHED_VERSION = pkg_resources.require("aws-service-catalog-puppet")[0].version
 VERSION_OVERRIDE = "SCP_VERSION_OVERRIDE"
 VERSION = os.getenv(VERSION_OVERRIDE, PUBLISHED_VERSION)
+
+
+PRODUCT_GENERATION_METHOD_DEFAULT = "copy"
